@@ -109,6 +109,13 @@ def dataframe_read_csv(csv: str) -> pd.DataFrame:
 
     list_raw_names = csv.split('\n')[0].split(',')  # first line from the csv (raw_names)
     is_fetch_bool, data_place_str = is_fetch_connexion(list_raw_names)
+    ls = []
+    for rn in list_raw_names:
+        try:
+            ls.append(raw_names_dict[rn]['metric_name'])
+        except Exception:
+            ls.append(rn + " Error")
+
     list_metrics_names = [raw_names_dict[raw_name]['metric_name'] for raw_name in list_raw_names]
 
     for metric_name in list_metrics_names:
